@@ -1,19 +1,8 @@
 /*
-    Copyright 2005 Thomas Nagy <tnagyemail-mail@yahoo.fr> 
-    Copyright 2007-2008 Fela Winkelmolen <fela.kde@gmail.com> 
-  
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
-   
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-   
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-FileCopyrightText: 2005 Thomas Nagy <tnagyemail-mail@yahoo.fr>
+    SPDX-FileCopyrightText: 2007-2008 Fela Winkelmolen <fela.kde@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include <KAboutData>
@@ -50,7 +39,7 @@ int main(int argc, char ** argv)
                          KAboutLicense::GPL, i18n("(C) 2004-2005 Andi Peredri, ported to KDE by Thomas Nagy\n"
                                                   "(C) 2007-2008 Fela Winkelmolen\n"
                                                   "(C) 2013 Ashwin Rajeev"), QString(),
-                         QStringLiteral("https://kde.org/applications/games/org.kde.knetwalk"));
+                         QStringLiteral("https://apps.kde.org/knetwalk"));
     
     about.addAuthor(i18n("Andi Peredri"),
                     i18n("original author"),
@@ -72,11 +61,10 @@ int main(int argc, char ** argv)
                     i18n("Port to use the QGraphicsView framework"),
                     QStringLiteral("brian.s.croom@gmail.com"));
 
-    about.setOrganizationDomain(QByteArray("kde.org"));
-    
     about.setProductName(QByteArray("knetwalk"));
     
     KAboutData::setApplicationData(about);
+
     QCommandLineParser parser;
     about.setupCommandLine(&parser);
     parser.process(app);
@@ -85,9 +73,6 @@ int main(int argc, char ** argv)
     KCrash::initialize();
     KDBusService service;
  
-    app.setApplicationDisplayName(about.displayName());
-    app.setOrganizationDomain(about.organizationDomain());
-    app.setApplicationVersion(about.version());
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("knetwalk")));
 
     MainWindow* window = new MainWindow;
